@@ -7,6 +7,7 @@ except ImportError:
     from PyQtX import QtCore
     from PyQtX import QtWidgets, QtWebKitWidgets
 
+import re
 import os
 import sys
 import time
@@ -61,28 +62,28 @@ class QVideoView(QtWebKitWidgets.QWebView):
         self.category_selected = "all"
         self.channel_selected = "all"
         self.verbose = verbose
+        self.pluzz = PluzzSearch(verbose=verbose)
 
     def handle_slots(self):
         self.page().mainFrame().addToJavaScriptWindowObject("qpluzz", self);
 
     def setup_topbar(self):
-        if len(self.topbar_channels) == 0 or len(self.topbar_categories) == 0:
-            with PluzzSearch(verbose=True) as s:
-                try:
-                    cat_l = [hb.LI(hb.CLASS("category"),
-                                    hb.A(c, href="javascript:void(0)")) for c in s.get_categories()]
-                    chn_l = [hb.LI(hb.CLASS("channel"),
-                                    hb.A(c, href="javascript:void(0)")) for c in s.get_channels()]
-                    self.topbar_channels = hb.UL(*(chn_l), id='channels')
-                    self.topbar_categories = hb.UL(*(cat_l), id='categories')
-                except Exception as err:
-                    if self.verbose:
-                        import traceback
-                        traceback.print_exc()
+        with self.pluzz as s:
+            try:
+                cat_l = [hb.LI(hb.CLASS("category") if c != self.category_selected else hb.CLASS("category selected"),
+                                hb.A(c, href="javascript:void(0)")) for c in s.get_categories()]
+                chn_l = [hb.LI(hb.CLASS("channel") if c != self.channel_selected else hb.CLASS("channel selected"),
+                                hb.A(c, href="javascript:void(0)")) for c in s.get_channels()]
+                self.topbar_channels = hb.UL(*(chn_l), id='channels')
+                self.topbar_categories = hb.UL(*(cat_l), id='categories')
+            except Exception as err:
+                if self.verbose:
+                    import traceback
+                    traceback.print_exc()
 
     def build_show_list(self, **args):
         self.setup_topbar()
-        with PluzzSearch(verbose=True) as s:
+        with self.pluzz as s:
             try:
                 shw_l = [hb.DIV(hb.CLASS("image"),
                                 hb.A(hb.CLASS("show"),
@@ -112,30 +113,30 @@ class QVideoView(QtWebKitWidgets.QWebView):
         self.page().mainFrame().evaluateJavaScript(SHOWS_JS)
 
     def build_show_data(self, i):
-        self.setup_topbar()
         with PluzzMovie(i) as m:
             try:
                 t_when = time.strftime(_("On %d %h %Y at %H:%M"), time.localtime(m['diffusion']['timestamp']))
                 # t_until = time.strftime(_("On %d %h %Y at %H:%M"), time.localtime(m['diffusion']['???']))
-                show_md = [hb.H1(_("Summary of the show '{}'").format(m['titre'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Id'))       , hb.SPAN(hb.CLASS('md_val'), m['id'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('AEDRA'))    , hb.SPAN(hb.CLASS('md_val'), m['id_aedra'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Broadcast')), hb.SPAN(hb.CLASS('md_val'), t_when)),
-                        #hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Until'))   , hb.SPAN(hb.CLASS('md_val'), t_until)),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Length'))   , hb.SPAN(hb.CLASS('md_val'), m['duree'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Genre'))    , hb.SPAN(hb.CLASS('md_val'), m['genre'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Season'))   , hb.SPAN(hb.CLASS('md_val'), str(m['saison']))),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Website'))  , hb.SPAN(hb.CLASS('md_val'), m['url_site'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Pluzz'))    , hb.SPAN(hb.CLASS('md_val'), m['url_reference'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Channel'))  , hb.SPAN(hb.CLASS('md_val'), m['chaine'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Picture'))  , hb.IMG(hb.CLASS('md_val'), src="http://pluzz.francetv.fr"+m['image'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Rights'))   , hb.SPAN(hb.CLASS('md_val'), m['droit']['csa'])),
-                        hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Crew'))     ,
+                show_md = [hb.H1(m['titre']),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Id'), ':')  , hb.SPAN(hb.CLASS('md_val'), m['id'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('AEDRA'), ':'), hb.SPAN(hb.CLASS('md_val'), m['id_aedra'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Broadcast'), ':'), hb.SPAN(hb.CLASS('md_val'), t_when)),
+                           #hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Until'), ':')   , hb.SPAN(hb.CLASS('md_val'), t_until)),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Length'), ':')   , hb.SPAN(hb.CLASS('md_val'), m['duree'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Genre'), ':')    , hb.SPAN(hb.CLASS('md_val'), m['genre'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Season'), ':')   , hb.SPAN(hb.CLASS('md_val'), str(m['saison']))),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Channel'), ':')  , hb.SPAN(hb.CLASS('md_val'), m['chaine'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Picture'), ':')  , hb.IMG(hb.CLASS('md_val'), src="http://pluzz.francetv.fr"+m['image'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Rights'), ':')   , hb.SPAN(hb.CLASS('md_val'), m['droit']['csa'])),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), hb.A(_('Website'), onclick='qpluzz.open_url({})'.format(m['url_site']), href="javascript:void(0)"))),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), hb.A(_('Pluzz'), onclick='qpluzz.open_url({})'.format(m['url_site']), href="javascript:void(0)"))),
+                           hb.DIV(hb.SPAN(hb.CLASS('md_key'), _('Crew'), ':')     ,
                                 hb.UL(hb.CLASS('crew_list'),
-                                        *([hb.LI(", ".join(p['fonctions']), ':', p['prenom'], p['nom']) for p in m['personnes']])
+                                            *([hb.LI(hb.UL(hb.SPAN(hb.CLASS('md_key'), ", ".join(p['fonctions']), ':'),
+                                                           hb.SPAN(hb.CLASS('md_val'), ' ', p['prenom'], ' ', p['nom']))) for p in m['personnes']])
                                         )
                                 ),
-                        hb.DIV(hb.CLASS('synopsis'), m['synopsis'])
+                           hb.P(hb.CLASS('synopsis'), m['synopsis'])
                         ]
             except Exception as err:
                 show_md = [str(err)]
@@ -144,10 +145,8 @@ class QVideoView(QtWebKitWidgets.QWebView):
                     traceback.print_exc()
 
         doc = hb.HTML(hb.HEAD(self.css_head),
-                      hb.BODY(hb.DIV(hb.A('X', href="javascript:void(0)"), id='back'),
-                              hb.DIV(hb.CLASS('header'),
-                                     self.topbar_channels,
-                                     self.topbar_categories),
+                      hb.BODY(hb.DIV(hb.A('×', href="javascript:void(0)"), id='back'),
+                              hb.DIV(hb.CLASS('header')),
                               hb.DIV(hb.CLASS('content'),
                                      hb.UL(*(show_md)))
                               )
@@ -158,10 +157,19 @@ class QVideoView(QtWebKitWidgets.QWebView):
         self.page().mainFrame().evaluateJavaScript(TOPBAR_JS)
         self.page().mainFrame().evaluateJavaScript(SHOW_JS)
 
+    @QtCore.pyqtSlot("QString")
+    def open_url(self, url):
+        print("open_url({})".format(url))
+        QtCore.QDesktopServices.openUrl(url)
+
     @QtCore.pyqtSlot()
     def goto_list(self):
+        if self.parent().in_download:
+            return
         self.parent().url_txt.setText('')
-        self.parent().start_btn.setEnabled(False)
+        self.parent().start_btn.setVisible(False)
+        self.parent().pbar.setVisible(False)
+        self.parent().eta.setVisible(False)
         self.build_show_list(channel=self.channel_selected,
                              category=self.category_selected,
                              limit=100, sort="alpha")
@@ -169,7 +177,9 @@ class QVideoView(QtWebKitWidgets.QWebView):
     @QtCore.pyqtSlot("QString")
     def select_show(self, i):
         self.parent().url_txt.setText(i)
-        self.parent().start_btn.setEnabled(True)
+        self.parent().start_btn.setVisible(True)
+        self.parent().pbar.setVisible(True)
+        self.parent().eta.setVisible(True)
         self.build_show_data(i)
 
     @QtCore.pyqtSlot("QString")
@@ -195,6 +205,7 @@ class QPluzz(QtWidgets.QWidget):
         super(QPluzz, self).__init__()
 
         self.defaults = args
+        self.in_download = False
 
         # row #0
         vbox = QtWidgets.QVBoxLayout()
@@ -206,9 +217,10 @@ class QPluzz(QtWidgets.QWidget):
         # row #2
         hbox = QtWidgets.QHBoxLayout()
         hbox.addStretch(1)
-        hbox.addWidget(QtWidgets.QLabel(_('URL of movie to load')))
+        hbox.addWidget(QtWidgets.QLabel(_('Search TV show')))
         self.url_txt = QtWidgets.QLineEdit()
         self.url_txt.setText(args['<id>'])
+        self.url_txt.editingFinished.connect(self.on_update_search)
         hbox.addWidget(self.url_txt)
         vbox.addLayout(hbox)
         # row #3
@@ -234,18 +246,37 @@ class QPluzz(QtWidgets.QWidget):
         # row #5
         self.start_btn = QtWidgets.QPushButton(_('Start Download!'))
         self.start_btn.clicked.connect(self.on_click_start)
-        if args['<id>']:
-            self.start_btn.setEnabled(True)
-        else:
-            self.start_btn.setEnabled(False)
         vbox.addWidget(self.start_btn)
         vbox.addStretch(1)
 
+        if args['<id>']:
+            self.eta.setVisible(True)
+            self.pbar.setVisible(True)
+            self.start_btn.setVisible(True)
+        else:
+            self.start_btn.setVisible(False)
+            self.pbar.setVisible(False)
+            self.eta.setVisible(False)
+
         self.setLayout(vbox)
 
         self.setWindowTitle(_('Pluzz Movie loader'))
         self.show()
 
+    re_match_id = re.compile(r'^\d+$')
+
+    @QtCore.pyqtSlot()
+    def on_update_search(self):
+        if self.url_txt.text().lstrip().startswith('http://'):
+            self.web_view.select_show(self.url_txt.text())
+        elif self.re_match_id.match(self.url_txt.text().lstrip()):
+            self.web_view.select_show(self.url_txt.text())
+        else:
+            self.web_view.build_show_list(channel=self.web_view.channel_selected,
+                                          category=self.web_view.category_selected,
+                                          query=self.url_txt.text(),
+                                          limit=100, sort="relevance")
+
     @QtCore.pyqtSlot()
     def on_click_start(self):
         def update_progress(position, total, spent, start):
@@ -258,10 +289,12 @@ class QPluzz(QtWidgets.QWidget):
 
         def dl(that):
             self.start_btn.setDisabled(True)
+            self.in_download = True
             movie.save(callback=update_progress, avconv_path=self.defaults['--avconv'], verbose=self.defaults['--verbose'])
             self.update_eta_text.emit("ETA -/-")
             self.update_progress_bar.emit(0)
             self.start_btn.setEnabled(True)
+            self.in_download = False
 
         with PluzzMovie(self.url_txt.text()) as movie:
             t = QtCore.QThread(self)
